@@ -1,11 +1,11 @@
 
 /*
  * CodeQuery
- * Copyright (C) 2013 ruben2020 https://github.com/ruben2020/
+ * Copyright (C) 2013-2016 ruben2020 https://github.com/ruben2020/
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
+ * the Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful,
@@ -18,7 +18,8 @@
  * 
  */
 
-
+#include <stdlib.h>
+#include <string.h>
 #include <QProcess>
 #include <QInputDialog>
 #include <QFontDatabase>
@@ -28,11 +29,19 @@
 #include <Qsci/qscilexerpython.h>
 #include <Qsci/qscilexerjava.h>
 #include <Qsci/qscilexerruby.h>
+#include <Qsci/qscilexerjavascript.h>
 
 #include "fileviewer.h"
 #include "mainwindow.h"
 #include "fileviewsettingsdialog.h"
 #include "themes.h"
+#include "std2qt.h"
+
+#ifdef USE_QT5
+#define QT45_TOASCII(x) toLatin1(x)
+#else
+#define QT45_TOASCII(x) toAscii(x)
+#endif
 
 #ifdef _WIN32
 #define EXT_EDITOR_DEFAULT_PATH "notepad %f"
@@ -43,28 +52,66 @@
 filedata::filedata()
 {
 	linenum = "1";
+	fileid = -99;
 }
-filedata::filedata(const QString& fn, const QString& ln)
+filedata::filedata(const QString& fn, const QString& ln, const int& fi)
 {
 	linenum = ln;
 	filename = fn;
+	fileid = fi;
 }
 
 bool filedata::compare(const filedata& fd)
 {
-	return ((linenum.compare(fd.linenum) == 0)&&
+	bool cmp;
+	if ((fileid < 0)||(fd.fileid < 0))
+	{
+		cmp = ((linenum.compare(fd.linenum) == 0)&&
 			(filename.compare(fd.filename) == 0));
+	}
+	else
+	{
+		cmp = ((linenum.compare(fd.linenum) == 0)&&
+			(fileid == fd.fileid));
+	}
+	return cmp;
 }
 
-bool filedata::compareFilenameOnly(const filedata& fd)
+bool filedata::compareFilePathOnly(const filedata& fd)
 {
-	return (filename.compare(fd.filename) == 0);
+	bool cmp;
+	if ((fileid < 0)||(fd.fileid < 0))
+	{
+		cmp = (filename.compare(fd.filename) == 0);
+	}
+	else
+	{
+		cmp = (fileid == fd.fileid);
+	}
+	return cmp;
+}
+
+bool filedata::compareFileNameOnly(const filedata& fd)
+{
+	bool cmp;
+	if ((fileid < 0)||(fd.fileid < 0))
+	{
+		cmp =(strcmp(
+		extract_filename(filename.QT45_TOASCII().data()),
+		extract_filename(fd.filename.QT45_TOASCII().data())) == 0);
+	}
+	else
+	{
+		cmp = (fileid == fd.fileid);
+	}
+	return cmp;
 }
 
 filedata::filedata(const filedata& fd)
 {
 	linenum = fd.linenum;
 	filename = fd.filename;
+	fileid = fd.fileid;
 }
 
 filedata& filedata::operator=(const filedata& fd)
@@ -73,6 +120,7 @@ filedata& filedata::operator=(const filedata& fd)
 	{
 		linenum = fd.linenum;
 		filename = fd.filename;
+		fileid = fd.fileid;
 	}
 	return *this;
 }
@@ -101,6 +149,7 @@ fileviewer::fileviewer(mainwindow* pmw)
 
 fileviewer::~fileviewer()
 {
+	disconnect();
 	if (m_lexer != NULL) delete m_lexer;
 }
 
@@ -158,12 +207,17 @@ void fileviewer::init(void)
 			this, SLOT(TextShrink_ButtonClick(bool)));
 	connect(m_pushButtonTextEnlarge, SIGNAL(clicked(bool)),
 			this, SLOT(TextEnlarge_ButtonClick(bool)));
+	connect(m_listWidgetFunc, SIGNAL(currentItemChanged(QListWidgetItem *, QListWidgetItem *)),
+			this, SLOT(funcItemSelected(QListWidgetItem *, QListWidgetItem *)));
+	connect(m_comboBoxFuncListSort, SIGNAL(currentIndexChanged(int)),
+			this, SLOT(FuncListSort_indexChanged(int)));
 	m_fileDataList.clear();
 	setLexer();
 }
 
 void fileviewer::clearList()
 {
+	//printf("Fileview clearlist\n");
 	m_pushButtonPaste->setEnabled(false);
 	m_pushButtonPrev->setEnabled(false);
 	m_pushButtonNext->setEnabled(false);
@@ -176,6 +230,7 @@ void fileviewer::clearList()
 	m_fileDataList.clear();
 	m_iter = m_fileDataList.begin();
 	m_timestampMismatchWarned = false;
+	m_listWidgetFunc->clear();
 }
 
 void fileviewer::recvDBtimestamp(QDateTime dt)
@@ -183,7 +238,7 @@ void fileviewer::recvDBtimestamp(QDateTime dt)
 	m_DBtimestamp = dt;
 }
 
-void fileviewer::fileToBeOpened(QString filename, QString linenum)
+void fileviewer::fileToBeOpened(QString filename, QString linenum, int fileid)
 {
 	filename.replace(QString("$HOME"), QDir::homePath());
 #ifdef _WIN32
@@ -215,9 +270,10 @@ void fileviewer::fileToBeOpened(QString filename, QString linenum)
 		msgBox.setText(tr("The source file to be viewed is newer than the CodeQuery database file. You are recommended to manually regenerate the CodeQuery database file."));
 		msgBox.exec();
 	}
-	filedata fd(filename, linenum);
+	filedata fd(filename, linenum, fileid);
 	if (m_fileDataList.isEmpty())
 	{
+		//printf("Fileviewer: empty list\n");
 		m_fileDataList.push_back(fd);
 		m_iter = m_fileDataList.end() - 1;
 		m_pushButtonPrev->setEnabled(false);
@@ -228,6 +284,7 @@ void fileviewer::fileToBeOpened(QString filename, QString linenum)
 	else if (m_iter == m_fileDataList.end())
 	{
 		// previous file not found
+		//printf("Fileviewer: previous file not found %d, %d\n", m_fileDataList.end(), m_fileDataList.end() - 1);
 		m_fileDataList.push_back(fd);
 		m_iter = m_fileDataList.end() - 1;
 		m_pushButtonPrev->setEnabled(m_iter != m_fileDataList.begin());
@@ -237,12 +294,14 @@ void fileviewer::fileToBeOpened(QString filename, QString linenum)
 	else if (m_iter->compare(fd))
 	{
 		// the same filename and line number
+		//printf("Fileviewer: same filename and line number\n");
 		updateFilePathLabel();
 		return;
 	}
-	else if (m_iter->compareFilenameOnly(fd))
+	else if (m_iter->compareFilePathOnly(fd))
 	{
 		// same file, different line number
+		//printf("Fileviewer: same file, different line number\n");
 		m_fileDataList.push_back(fd);
 		m_iter = m_fileDataList.end() - 1;
 		m_pushButtonPrev->setEnabled(true);
@@ -253,19 +312,22 @@ void fileviewer::fileToBeOpened(QString filename, QString linenum)
 	else
 	{
 		// different file
+		//printf("Fileviewer: different file\n");
 		m_fileDataList.push_back(fd);
 		m_iter = m_fileDataList.end() - 1;
 		m_pushButtonPrev->setEnabled(true);
 		m_pushButtonNext->setEnabled(false);
 		updateTextEdit();
 	}
+	if ((m_fileDataList.isEmpty())||(m_iter == m_fileDataList.end())) return;
 	QVector<filedata>::iterator it = m_fileDataList.begin();
 	while ((it != m_fileDataList.end() - 1)&&(it != m_fileDataList.end()))
 	{
-		if (it->compare(fd)) m_fileDataList.erase(it);
+		if (it->compare(fd)) it = m_fileDataList.erase(it);
 		else it++;
 	}
 	if (m_fileDataList.size() > 20) m_fileDataList.erase(m_fileDataList.begin());
+	m_iter = m_fileDataList.end() - 1;
 }
 
 void fileviewer::updateTextEdit(void)
@@ -296,6 +358,10 @@ void fileviewer::updateTextEdit(void)
 	pos = rx3.indexIn(m_iter->filename);
 	if (pos != -1) lang = enHighlightRuby;
 
+	QRegExp rx4("\\.js$", Qt::CaseInsensitive);
+	pos = rx4.indexIn(m_iter->filename);
+	if (pos != -1) lang = enHighlightJavascript;
+
 	m_currentlang = lang;
 	setLexer(lang);
 
@@ -312,6 +378,9 @@ void fileviewer::updateTextEdit(void)
 	m_pushButtonOpenInEditor->setEnabled(true);
 	m_pushButtonTextShrink->setEnabled(true);
 	m_pushButtonTextEnlarge->setEnabled(true);
+	m_listWidgetFunc->clear();
+	if (m_iter->fileid < 0)	{emit requestFuncList_filename(m_iter->filename);}
+	else {emit requestFuncList_fileid(m_iter->fileid);}
 	QApplication::restoreOverrideCursor();
 }
 
@@ -362,7 +431,7 @@ void fileviewer::Prev_ButtonClick(bool checked)
 	{
 		QVector<filedata>::iterator it = m_iter;
 		m_iter--;
-		if ((it != m_fileDataList.end())&&(m_iter->compareFilenameOnly(*it)))
+		if ((it != m_fileDataList.end())&&(m_iter->compareFilePathOnly(*it)))
 		{
 			highlightLine(m_iter->linenum.toInt());
 			updateFilePathLabel();			
@@ -394,7 +463,7 @@ void fileviewer::Next_ButtonClick(bool checked)
 	{
 		QVector<filedata>::iterator it = m_iter;
 		m_iter++;
-		if (m_iter->compareFilenameOnly(*it))
+		if (m_iter->compareFilePathOnly(*it))
 		{
 			highlightLine(m_iter->linenum.toInt());
 			updateFilePathLabel();			
@@ -410,6 +479,7 @@ void fileviewer::Next_ButtonClick(bool checked)
 
 void fileviewer::handleFileCannotBeOpenedCase(void)
 {
+	//printf("handleFileCannotBeOpenedCase\n");
 	m_textEditSource->clear();
 	m_pushButtonTextShrink->setEnabled(false);
 	m_pushButtonTextEnlarge->setEnabled(false);
@@ -618,6 +688,10 @@ void fileviewer::setLexer(int lang)
 			replaceLexer("Ruby", lang);
 			break;
 
+		case enHighlightJavascript:
+			replaceLexer("JavaScript", lang);
+			break;
+
 		default:
 			replaceLexer("C++", lang);
 			break;
@@ -630,7 +704,8 @@ void fileviewer::replaceLexer(const char* langstr, int lang)
 {
 	QColor markerlinebgcolor;
 	QColor linenumfgcolor;
-	if (strcmp(m_lexer->language(), langstr) != 0)
+	if ((strlen(m_lexer->language()) != strlen(langstr)) ||
+		(strcmp(m_lexer->language(), langstr) != 0))
 	{
 		m_textEditSource->setLexer(NULL);
 		delete m_lexer;
@@ -652,6 +727,10 @@ void fileviewer::replaceLexer(const char* langstr, int lang)
 				m_lexer = new QsciLexerRuby(m_textEditSource);
 				break;
 
+			case enHighlightJavascript:
+				m_lexer = new QsciLexerJavaScript(m_textEditSource);
+				break;
+
 			default:
 				m_lexer = new QsciLexerCPP(m_textEditSource);
 				break;
@@ -681,4 +760,47 @@ void fileviewer::annotate(QString annotstr)
 	m_textEditSource->annotate(m_annotline, annotstr, 29);
 }
 
+void fileviewer::recvFuncList(sqlqueryresultlist* reslist)
+{
+	m_listWidgetFunc->clear();
+	if ((m_fileDataList.isEmpty())||(m_iter == m_fileDataList.end())) return;
+	m_funclist = *reslist;
+	filedata fd(str2qt(m_funclist.resultlist[0].filename), "1", -99);
+	if (m_iter->compareFileNameOnly(fd) == false)
+	{
+		if (m_iter->fileid < 0)	{emit requestFuncList_filename(m_iter->filename);}
+		else {emit requestFuncList_fileid(m_iter->fileid);}
+		return;
+	}
+	if (m_comboBoxFuncListSort->currentIndex() == 0)
+		{m_funclist.sort_by_linenum();}
+	else
+		{m_funclist.sort_by_name();}
+	for (int i=0; i < m_funclist.resultlist.size(); i++)
+	{
+		m_listWidgetFunc->addItem(new QListWidgetItem(
+			str2qt(m_funclist.resultlist[i].symname), 0, 
+			atoi(m_funclist.resultlist[i].linenum.c_str())));
+	}
+}
+
+void fileviewer::funcItemSelected(QListWidgetItem * curitem, QListWidgetItem * previtem)
+{
+	if (curitem == NULL) return;
+	int num = curitem->type();
+	if (num <= 0)
+	{
+		num = 1;
+	}
+	else
+	{
+		num = num - 1; // not sure why it's one off
+	}
+	m_textEditSource->ensureLineVisible(num);
+}
+
+void fileviewer::FuncListSort_indexChanged(const int& idx)
+{
+	recvFuncList(&m_funclist);
+}
 
