@@ -1,11 +1,11 @@
-	
+
 /*
  * CodeQuery
- * Copyright (C) 2013 ruben2020 https://github.com/ruben2020/
+ * Copyright (C) 2013-2016 ruben2020 https://github.com/ruben2020/
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
+ * the Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful,
@@ -18,7 +18,6 @@
  * 
  */
 
-
 #include <QVector>
 #include "std2qt.h"
 #include "graphdialog.h"
@@ -91,6 +90,7 @@ searchhandler::searchhandler(mainwindow* pmw)
 ,m_typeOfGraph(1)
 ,m_autocompBusy(false)
 ,m_declarBusy(false)
+,m_funcListBusy(false)
 {
 	sq = new sqlqueryadv;
 	m_completer = new QCompleter(&m_srchStrLstModel, (QWidget*)mw);
@@ -150,7 +150,7 @@ void searchhandler::searchTextEdited(const QString& searchtxt)
 {
 	if (m_checkBoxAutoComplete->isChecked())
 	{
-		if ((m_autocompBusy)||(m_declarBusy))
+		if ((m_autocompBusy)||(m_declarBusy)||(m_funcListBusy))
 		{
 			m_autocompSrchTerm = searchtxt;
 		}
@@ -186,13 +186,13 @@ void searchhandler::declarSearchFinished()
 {
 	QString str = m_declarFutureWatcher.result();
 	if (str.length() > 0)
-		emit searchDeclarationResultsReady(m_declarFutureWatcher.result());
+		emit searchDeclarationResultsReady(str);
 	m_declarBusy = false;
 }
 
 void searchhandler::searchDeclaration(QString searchstr)
 {
-	if ((!m_declarBusy)&&(!m_autocompBusy))
+	if ((!m_declarBusy)&&(!m_autocompBusy)&&(!m_funcListBusy))
 	{
 		m_declarBusy = true;
 		m_declarFutureWatcher.setFuture(
@@ -200,6 +200,47 @@ void searchhandler::searchDeclaration(QString searchstr)
 	}
 }
 
+void searchhandler::funcListSearchFinished()
+{
+	sqlqueryresultlist res = m_listFuncFutureWatcher.result();
+	if ((res.result_type == sqlqueryresultlist::sqlresultFUNC_IN_ONE_FILE) &&
+		(res.resultlist.empty() == false))
+	{
+		emit searchListFuncResultsReady(&res);
+	}
+	m_funcListBusy = false;
+}
+
+void searchhandler::searchFuncList_filename(QString filename)
+{
+	if ((filename.isEmpty() == false)&&(!m_declarBusy)&&(!m_autocompBusy)&&(!m_funcListBusy))
+	{
+		m_funcListBusy = true;
+		m_listFuncFutureWatcher.setFuture(
+			QtConcurrent::run(search_funclist_qt_filename, filename));
+	}
+}
+
+void searchhandler::searchFuncList_fileid(int fileid)
+{
+	if ((fileid >= 0)&&(!m_declarBusy)&&(!m_autocompBusy)&&(!m_funcListBusy))
+	{
+		m_funcListBusy = true;
+		m_listFuncFutureWatcher.setFuture(
+			QtConcurrent::run(search_funclist_qt_fileid, fileid));
+	}
+}
+
+sqlqueryresultlist searchhandler::search_funclist_qt_filename(QString filename)
+{
+	return sq->search_funclist_filename(extract_filename(filename.QT45_TOASCII().data()));
+}
+
+sqlqueryresultlist searchhandler::search_funclist_qt_fileid(int fileid)
+{
+	return sq->search_funclist_fileid(fileid);
+}
+
 QString searchhandler::search_declaration_qt(QString searchtxt)
 {
 	QString str;
@@ -279,6 +320,8 @@ void searchhandler::init(void)
 			this, SLOT(autoCompleteFinished()));
 	connect(&m_declarFutureWatcher, SIGNAL(finished()),
 			this, SLOT(declarSearchFinished()));
+	connect(&m_listFuncFutureWatcher, SIGNAL(finished()),
+			this, SLOT(funcListSearchFinished()));
 }
 
 void searchhandler::retranslateUi(void)
@@ -369,6 +412,11 @@ void searchhandler::OpenDB_indexChanged(const int& idx)
 		m_declarBusy = false;
 		m_declarFutureWatcher.waitForFinished();
 	}
+	if (m_funcListBusy)
+	{
+		m_funcListBusy = false;
+		m_listFuncFutureWatcher.waitForFinished();
+	}
 	sq->close_dbfile();
 	QFileInfo dbfile(m_comboBoxDB->itemText(idx));
 	sqstatus = sq->open_dbfile(qt2str(m_comboBoxDB->itemText(idx)));
@@ -451,6 +499,11 @@ void searchhandler::perform_search(QString searchtxt,
 		m_declarBusy = false;
 		m_declarFutureWatcher.waitForFinished();
 	}
+	if (m_funcListBusy)
+	{
+		m_funcListBusy = false;
+		m_listFuncFutureWatcher.waitForFinished();
+	}
 	sqlquery::en_queryType querytype = qrytyp;
 	if (querytype == sqlquery::sqlresultDEFAULT) querytype = 
 		(sqlquery::en_queryType)m_comboBoxQueryType->itemData(m_comboBoxQueryType->currentIndex()).toInt();
@@ -614,7 +667,7 @@ void searchhandler::resultCurrentListItemSymbolName(const QString symName)
 		return;
 	}	
 
-	QString grpxml, grpdot;
+	QStringList grpxml, grpdot;
 	bool res;
 	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 	if (m_autocompBusy)
@@ -627,14 +680,26 @@ void searchhandler::resultCurrentListItemSymbolName(const QString symName)
 		m_declarBusy = false;
 		m_declarFutureWatcher.waitForFinished();
 	}
+	if (m_funcListBusy)
+	{
+		m_funcListBusy = false;
+		m_listFuncFutureWatcher.waitForFinished();
+	}
 	if (m_typeOfGraph == 1)
-	res = sq->search_funcgraph(symName,
-			true,
-			grpxml, grpdot);
+	{
+		res = sq->search_funcgraph(symName,
+				true,
+				grpxml, grpdot);
+		res = sq->search_funcgraph(symName,
+				true,
+				grpxml, grpdot, 2);
+	}
 	else if (m_typeOfGraph == 2)
-	res = sq->search_classinheritgraph(symName,
-			true,
-			grpxml, grpdot);
+	{
+		res = sq->search_classinheritgraph(symName,
+				true,
+				grpxml, grpdot);
+	}
 	else {QApplication::restoreOverrideCursor(); return;}
 	QApplication::restoreOverrideCursor();
 	QMessageBox msgBox((QWidget*)mw);
