@@ -1,11 +1,11 @@
 
 /*
  * CodeQuery
- * Copyright (C) 2013 ruben2020 https://github.com/ruben2020/
+ * Copyright (C) 2013-2016 ruben2020 https://github.com/ruben2020/
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
+ * the Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful,
@@ -34,8 +34,8 @@ public:
 	sqlqueryadv();
 	~sqlqueryadv();
 
-bool search_funcgraph(QString searchstr, bool exactmatch, QString& xmlout, QString& dotout);
-bool search_classinheritgraph(QString searchstr, bool exactmatch, QString& xmlout, QString& dotout);
+bool search_funcgraph(QString searchstr, bool exactmatch, QStringList& xmlout, QStringList& dotout, int levels = 1);
+bool search_classinheritgraph(QString searchstr, bool exactmatch, QStringList& xmlout, QStringList& dotout);
 void unique_symnames(sqlqueryresultlist& res);
 void remove_symname(sqlqueryresultlist& res, tStr name);
 
