@@ -14,35 +14,40 @@
         <translation>お待ちください。。。</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="64"/>
-        <location filename="../ui/graphDialog.ui" line="67"/>
+        <location filename="../ui/graphDialog.ui" line="70"/>
+        <location filename="../ui/graphDialog.ui" line="73"/>
         <source>Zoom Out</source>
         <translation>ズーム アウト</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="81"/>
-        <location filename="../ui/graphDialog.ui" line="84"/>
+        <location filename="../ui/graphDialog.ui" line="93"/>
+        <location filename="../ui/graphDialog.ui" line="96"/>
         <source>Zoom In</source>
         <translation>ズームインします。</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="104"/>
-        <location filename="../ui/graphDialog.ui" line="107"/>
-        <location filename="../ui/graphDialog.ui" line="110"/>
+        <location filename="../ui/graphDialog.ui" line="123"/>
+        <source>Number of levels:</source>
+        <translation>レベル数:</translation>
+    </message>
+    <message>
+        <location filename="../ui/graphDialog.ui" line="153"/>
+        <location filename="../ui/graphDialog.ui" line="156"/>
+        <location filename="../ui/graphDialog.ui" line="159"/>
         <source>Save to DOT file</source>
         <translation>ドット ファイルに保存します。</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="123"/>
-        <location filename="../ui/graphDialog.ui" line="126"/>
-        <location filename="../ui/graphDialog.ui" line="129"/>
+        <location filename="../ui/graphDialog.ui" line="172"/>
+        <location filename="../ui/graphDialog.ui" line="175"/>
+        <location filename="../ui/graphDialog.ui" line="178"/>
         <source>Save Image</source>
         <translation>画像を保存します。</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="142"/>
-        <location filename="../ui/graphDialog.ui" line="145"/>
-        <location filename="../ui/graphDialog.ui" line="148"/>
+        <location filename="../ui/graphDialog.ui" line="191"/>
+        <location filename="../ui/graphDialog.ui" line="194"/>
+        <location filename="../ui/graphDialog.ui" line="197"/>
         <source>Close</source>
         <translation>閉じる</translation>
     </message>
@@ -55,196 +60,206 @@
         <translation>CodeQuery</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="29"/>
-        <location filename="../ui/mainWindow.ui" line="32"/>
+        <location filename="../ui/mainWindow.ui" line="27"/>
+        <location filename="../ui/mainWindow.ui" line="30"/>
         <source>Open Database</source>
         <translation>データベースを開く</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="69"/>
+        <location filename="../ui/mainWindow.ui" line="76"/>
         <source>Auto-complete</source>
         <translation>自動車-完全な</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="83"/>
+        <location filename="../ui/mainWindow.ui" line="90"/>
         <source>Exact match</source>
         <translation>完全に一致します。</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="97"/>
-        <location filename="../ui/mainWindow.ui" line="100"/>
+        <location filename="../ui/mainWindow.ui" line="104"/>
+        <location filename="../ui/mainWindow.ui" line="107"/>
         <source>File path filter</source>
         <translation>ファイル パス フィルター</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="103"/>
+        <location filename="../ui/mainWindow.ui" line="110"/>
         <source>Filter</source>
         <translation>フィルター</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="119"/>
-        <location filename="../ui/mainWindow.ui" line="122"/>
+        <location filename="../ui/mainWindow.ui" line="126"/>
+        <location filename="../ui/mainWindow.ui" line="129"/>
         <source>File path filter, wildcard searches (* and ?) are supported</source>
         <translation>ファイル パス フィルター、ワイルドカード検索 (* と?) がサポートされています</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="145"/>
-        <location filename="../ui/mainWindow.ui" line="148"/>
+        <location filename="../ui/mainWindow.ui" line="152"/>
+        <location filename="../ui/mainWindow.ui" line="155"/>
         <source>Previous search term</source>
         <translation>前の検索クエリ</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="162"/>
-        <location filename="../ui/mainWindow.ui" line="165"/>
+        <location filename="../ui/mainWindow.ui" line="175"/>
+        <location filename="../ui/mainWindow.ui" line="178"/>
         <source>Next search term</source>
         <translation>次の検索用語</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="185"/>
-        <location filename="../ui/mainWindow.ui" line="188"/>
+        <location filename="../ui/mainWindow.ui" line="204"/>
+        <location filename="../ui/mainWindow.ui" line="207"/>
         <source>If Exact Match is switched off, wildcard searches (* and ?) are supported</source>
         <translation>完全に一致するワイルドカード検索を切り替えた場合 (* と?) サポートされています。</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="204"/>
-        <location filename="../ui/mainWindow.ui" line="207"/>
+        <location filename="../ui/mainWindow.ui" line="226"/>
+        <location filename="../ui/mainWindow.ui" line="229"/>
         <source>Search</source>
         <translation>検索</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="221"/>
-        <location filename="../ui/mainWindow.ui" line="224"/>
+        <location filename="../ui/mainWindow.ui" line="249"/>
+        <location filename="../ui/mainWindow.ui" line="252"/>
         <source>Paste and Search</source>
         <translation>貼り付け、検索</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="241"/>
-        <location filename="../ui/mainWindow.ui" line="244"/>
+        <location filename="../ui/mainWindow.ui" line="275"/>
+        <location filename="../ui/mainWindow.ui" line="278"/>
         <source>Draw graph</source>
         <translation>グラフを描く</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="295"/>
-        <location filename="../ui/mainWindow.ui" line="298"/>
+        <location filename="../ui/mainWindow.ui" line="335"/>
+        <location filename="../ui/mainWindow.ui" line="338"/>
         <source>Previous File</source>
         <translation>以前のファイル</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="312"/>
-        <location filename="../ui/mainWindow.ui" line="315"/>
+        <location filename="../ui/mainWindow.ui" line="358"/>
+        <location filename="../ui/mainWindow.ui" line="361"/>
         <source>Next File</source>
         <translation>次のファイル</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="329"/>
-        <location filename="../ui/mainWindow.ui" line="332"/>
+        <location filename="../ui/mainWindow.ui" line="381"/>
+        <location filename="../ui/mainWindow.ui" line="384"/>
         <source>Open in Editor</source>
         <translation>エディターで開く</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="346"/>
-        <location filename="../ui/mainWindow.ui" line="349"/>
+        <location filename="../ui/mainWindow.ui" line="404"/>
+        <location filename="../ui/mainWindow.ui" line="407"/>
         <source>Go to selected line</source>
         <translation>選択した行に移動します。</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="363"/>
-        <location filename="../ui/mainWindow.ui" line="366"/>
+        <location filename="../ui/mainWindow.ui" line="427"/>
+        <location filename="../ui/mainWindow.ui" line="430"/>
         <source>Reduce font size</source>
         <translation>フォント サイズを小さく</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="380"/>
-        <location filename="../ui/mainWindow.ui" line="383"/>
+        <location filename="../ui/mainWindow.ui" line="450"/>
+        <location filename="../ui/mainWindow.ui" line="453"/>
         <source>Increase font size</source>
         <translation>フォント サイズを大きく</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="404"/>
-        <location filename="../ui/mainWindow.ui" line="407"/>
+        <location filename="../ui/mainWindow.ui" line="480"/>
+        <location filename="../ui/mainWindow.ui" line="483"/>
         <source>Copy, paste and search</source>
         <translation>コピー、貼り付け、検索</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="421"/>
-        <location filename="../ui/mainWindow.ui" line="424"/>
+        <location filename="../ui/mainWindow.ui" line="503"/>
+        <location filename="../ui/mainWindow.ui" line="506"/>
         <source>Symbol search only for paste and search</source>
         <translation>シンボル検索は、貼り付け、検索のみ</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="427"/>
+        <location filename="../ui/mainWindow.ui" line="509"/>
         <source>Symbol only</source>
         <translation>シンボルのみ</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="441"/>
-        <location filename="../ui/mainWindow.ui" line="444"/>
+        <location filename="../ui/mainWindow.ui" line="523"/>
+        <location filename="../ui/mainWindow.ui" line="526"/>
         <source>Previous search result in this file</source>
         <translation>このファイルの前の検索結果</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="458"/>
-        <location filename="../ui/mainWindow.ui" line="461"/>
+        <location filename="../ui/mainWindow.ui" line="546"/>
+        <location filename="../ui/mainWindow.ui" line="549"/>
         <source>Next search result in this file</source>
         <translation>このファイルの次の検索結果</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="487"/>
+        <location filename="../ui/mainWindow.ui" line="581"/>
         <source>FilePath:0</source>
         <translation>FilePath:0</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="528"/>
+        <location filename="../ui/mainWindow.ui" line="610"/>
+        <source>Sort by line number</source>
+        <translation>行番号順に並べ替えます</translation>
+    </message>
+    <message>
+        <location filename="../ui/mainWindow.ui" line="615"/>
+        <source>Sort by name</source>
+        <translation>名前順に並べ替えます</translation>
+    </message>
+    <message>
+        <location filename="../ui/mainWindow.ui" line="665"/>
         <source>File</source>
         <translation>ファイル</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="535"/>
+        <location filename="../ui/mainWindow.ui" line="672"/>
         <source>Options</source>
         <translation>オプション</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="543"/>
+        <location filename="../ui/mainWindow.ui" line="680"/>
         <source>Help</source>
         <translation>ヘルプ</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="555"/>
+        <location filename="../ui/mainWindow.ui" line="692"/>
         <source>Exit</source>
         <translation>終了</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="563"/>
+        <location filename="../ui/mainWindow.ui" line="700"/>
         <source>Open</source>
         <translation>オープン</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="568"/>
+        <location filename="../ui/mainWindow.ui" line="705"/>
         <source>About</source>
         <translation>について</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="573"/>
+        <location filename="../ui/mainWindow.ui" line="710"/>
         <source>External Editor</source>
         <translation>外部エディター</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="578"/>
+        <location filename="../ui/mainWindow.ui" line="715"/>
         <source>Open CQ Database</source>
         <translation>オープン cq, データベース</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="583"/>
+        <location filename="../ui/mainWindow.ui" line="720"/>
         <source>Language</source>
         <translation>言語</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="588"/>
+        <location filename="../ui/mainWindow.ui" line="725"/>
         <source>About Qt</source>
         <translation>Qt について</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="596"/>
+        <location filename="../ui/mainWindow.ui" line="733"/>
         <source>File Viewer Settings</source>
         <translation>ファイル ビューアーの設定</translation>
     </message>
@@ -265,23 +280,23 @@
 <context>
     <name>cqDialogGraph</name>
     <message>
-        <location filename="../graphdialog.cpp" line="78"/>
+        <location filename="../graphdialog.cpp" line="89"/>
         <source>Images</source>
         <translation>画像</translation>
     </message>
     <message>
-        <location filename="../graphdialog.cpp" line="81"/>
+        <location filename="../graphdialog.cpp" line="92"/>
         <source>Export Image</source>
         <translation>イメージをエクスポートします。</translation>
     </message>
     <message>
-        <location filename="../graphdialog.cpp" line="92"/>
-        <location filename="../graphdialog.cpp" line="111"/>
+        <location filename="../graphdialog.cpp" line="103"/>
+        <location filename="../graphdialog.cpp" line="122"/>
         <source>File could not be saved!</source>
         <translation>ファイルを保存できませんでした ！</translation>
     </message>
     <message>
-        <location filename="../graphdialog.cpp" line="100"/>
+        <location filename="../graphdialog.cpp" line="111"/>
         <source>Export DOT file</source>
         <translation>ドット ファイルをエクスポートします。</translation>
     </message>
@@ -322,62 +337,62 @@
 <context>
     <name>fileviewer</name>
     <message>
-        <location filename="../fileviewer.cpp" line="189"/>
+        <location filename="../fileviewer.cpp" line="249"/>
         <source>File not found</source>
         <translation>ファイルが見つかりません</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="196"/>
+        <location filename="../fileviewer.cpp" line="256"/>
         <source>File could not be opened</source>
         <translation>ファイルを開くことができません。</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="210"/>
+        <location filename="../fileviewer.cpp" line="270"/>
         <source>The source file to be viewed is newer than the CodeQuery database file. You are recommended to manually regenerate the CodeQuery database file.</source>
         <translation>ソース ファイルを表示するのには、CodeQuery データベース ファイルよりも新しいです。CodeQuery データベース ファイルを手動で再生成に推奨されます。</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="447"/>
+        <location filename="../fileviewer.cpp" line="533"/>
         <source>Cancel</source>
         <translation>キャンセル</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="448"/>
+        <location filename="../fileviewer.cpp" line="534"/>
         <source>OK</source>
         <translation>わかりました</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="450"/>
+        <location filename="../fileviewer.cpp" line="536"/>
         <source>External Editor Configuration</source>
         <translation>外部エディターの構成</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="451"/>
+        <location filename="../fileviewer.cpp" line="537"/>
         <source>Please enter the path and arguments for the external editor. Replace as follows:</source>
         <translation>外部エディターの引数とパスを入力してください。次のように置き換えます。</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="453"/>
+        <location filename="../fileviewer.cpp" line="539"/>
         <source>for file path</source>
         <translation>ファイルのパス</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="455"/>
+        <location filename="../fileviewer.cpp" line="541"/>
         <source>for line number</source>
         <translation>行番号について</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="457"/>
+        <location filename="../fileviewer.cpp" line="543"/>
         <source>For example:</source>
         <translation>たとえば。</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="482"/>
+        <location filename="../fileviewer.cpp" line="568"/>
         <source>File could not be opened!</source>
         <translation>ファイルを開くことができません ！</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="507"/>
+        <location filename="../fileviewer.cpp" line="593"/>
         <source>External editor could not be started. Please check Options!</source>
         <translation>外部エディターを開始できませんでした。オプションを確認してください ！</translation>
     </message>
@@ -385,22 +400,22 @@
 <context>
     <name>listhandler</name>
     <message>
-        <location filename="../listhandler.cpp" line="128"/>
+        <location filename="../listhandler.cpp" line="129"/>
         <source>Symbol</source>
         <translation>シンボル</translation>
     </message>
     <message>
-        <location filename="../listhandler.cpp" line="129"/>
+        <location filename="../listhandler.cpp" line="130"/>
         <source>File</source>
         <translation>ファイル</translation>
     </message>
     <message>
-        <location filename="../listhandler.cpp" line="132"/>
+        <location filename="../listhandler.cpp" line="133"/>
         <source>Line</source>
         <translation>ライン</translation>
     </message>
     <message>
-        <location filename="../listhandler.cpp" line="132"/>
+        <location filename="../listhandler.cpp" line="133"/>
         <source>Preview</source>
         <translation>プレビュー</translation>
     </message>
@@ -408,22 +423,22 @@
 <context>
     <name>mainwindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="156"/>
+        <location filename="../mainwindow.cpp" line="168"/>
         <source>Cancel</source>
         <translation>キャンセル</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="157"/>
+        <location filename="../mainwindow.cpp" line="169"/>
         <source>OK</source>
         <translation>わかりました</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="159"/>
+        <location filename="../mainwindow.cpp" line="171"/>
         <source>Language</source>
         <translation>言語</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="160"/>
+        <location filename="../mainwindow.cpp" line="172"/>
         <source>Select language:</source>
         <translation>言語の選択：</translation>
     </message>
@@ -431,138 +446,138 @@
 <context>
     <name>searchhandler</name>
     <message>
-        <location filename="../searchhandler.cpp" line="250"/>
+        <location filename="../searchhandler.cpp" line="334"/>
         <source>Symbol</source>
         <translation>シンボル</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="253"/>
+        <location filename="../searchhandler.cpp" line="337"/>
         <source>Function or macro definition (Graph available)</source>
         <translation>関数またはマクロの定義 (グラフ)</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="265"/>
+        <location filename="../searchhandler.cpp" line="349"/>
         <source>Class or struct (Graph available)</source>
         <translation>クラスまたは構造体 (利用可能なグラフ)</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="259"/>
+        <location filename="../searchhandler.cpp" line="343"/>
         <source>Functions calling this function</source>
         <translation>この関数を呼び出す関数</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="262"/>
+        <location filename="../searchhandler.cpp" line="346"/>
         <source>Functions called by this function</source>
         <translation>この関数によって呼び出された関数</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="256"/>
+        <location filename="../searchhandler.cpp" line="340"/>
         <source>Calls of this function or macro</source>
         <translation>この関数やマクロの呼び出し</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="268"/>
+        <location filename="../searchhandler.cpp" line="352"/>
         <source>Class which owns this member or method</source>
         <translation>このメンバーまたはメソッドを所有しているクラス</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="271"/>
+        <location filename="../searchhandler.cpp" line="355"/>
         <source>Members or methods of this class</source>
         <translation>このクラスのメンバーやメソッド</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="274"/>
+        <location filename="../searchhandler.cpp" line="358"/>
         <source>Parent of this class</source>
         <translation>このクラスの親</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="277"/>
+        <location filename="../searchhandler.cpp" line="361"/>
         <source>Children of this class</source>
         <translation>このクラスの子供たち</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="280"/>
+        <location filename="../searchhandler.cpp" line="364"/>
         <source>Files including this file</source>
         <translation>このファイルを含むファイル</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="283"/>
+        <location filename="../searchhandler.cpp" line="367"/>
         <source>Full path for file</source>
         <translation>ファイルの完全なパス</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="286"/>
+        <location filename="../searchhandler.cpp" line="370"/>
         <source>Functions or macros inside this file</source>
         <translation>関数またはこのファイル内のマクロ</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="297"/>
+        <location filename="../searchhandler.cpp" line="381"/>
         <source>CodeQuery DB Files</source>
         <translation>CodeQuery DB ファイル</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="300"/>
+        <location filename="../searchhandler.cpp" line="384"/>
         <source>Open CQ database file</source>
         <translation>Cq, データベース ファイルを開く</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="359"/>
+        <location filename="../searchhandler.cpp" line="453"/>
         <source>Function Call Graph</source>
         <translation>関数コール グラフ</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="363"/>
+        <location filename="../searchhandler.cpp" line="457"/>
         <source>Class Inheritance Graph</source>
         <translation>クラス継承グラフ</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="379"/>
-        <location filename="../searchhandler.cpp" line="382"/>
+        <location filename="../searchhandler.cpp" line="473"/>
+        <location filename="../searchhandler.cpp" line="476"/>
         <source>If Exact Match is switched off, wildcard searches (* and ?) are supported</source>
         <translation>完全に一致するワイルドカード検索を切り替えた場合 (* と?) サポートされています。</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="444"/>
+        <location filename="../searchhandler.cpp" line="548"/>
         <source>results found</source>
         <translation>検索結果</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="463"/>
+        <location filename="../searchhandler.cpp" line="567"/>
         <source>in progress</source>
         <translation>進行中</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="464"/>
+        <location filename="../searchhandler.cpp" line="568"/>
         <source>Cancel</source>
         <translation>キャンセル</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="561"/>
+        <location filename="../searchhandler.cpp" line="665"/>
         <source>You have to first select an item from the list before pushing the Graph button.</source>
         <translation>[グラフ] ボタンを押す前にまず一覧から項目を選択する必要があります。</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="673"/>
+        <location filename="../searchhandler.cpp" line="794"/>
         <source>File open error</source>
         <translation>ファイルを開くエラー</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="674"/>
+        <location filename="../searchhandler.cpp" line="795"/>
         <source>Wrong file format</source>
         <translation>ファイル フォーマット</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="675"/>
+        <location filename="../searchhandler.cpp" line="796"/>
         <source>Incorrect CQ database version</source>
         <translation>Cq, データベース バージョンが正しくないです。</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="676"/>
+        <location filename="../searchhandler.cpp" line="797"/>
         <source>OK</source>
         <translation>わかりました</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="678"/>
+        <location filename="../searchhandler.cpp" line="799"/>
         <source>Unknown Error</source>
         <translation>不明なエラー</translation>
     </message>
