@@ -14,35 +14,40 @@
         <translation>잠시만 기다려 주십시오...</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="64"/>
-        <location filename="../ui/graphDialog.ui" line="67"/>
+        <location filename="../ui/graphDialog.ui" line="70"/>
+        <location filename="../ui/graphDialog.ui" line="73"/>
         <source>Zoom Out</source>
         <translation>축소</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="81"/>
-        <location filename="../ui/graphDialog.ui" line="84"/>
+        <location filename="../ui/graphDialog.ui" line="93"/>
+        <location filename="../ui/graphDialog.ui" line="96"/>
         <source>Zoom In</source>
         <translation>확대</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="104"/>
-        <location filename="../ui/graphDialog.ui" line="107"/>
-        <location filename="../ui/graphDialog.ui" line="110"/>
+        <location filename="../ui/graphDialog.ui" line="123"/>
+        <source>Number of levels:</source>
+        <translation>수준의 수:</translation>
+    </message>
+    <message>
+        <location filename="../ui/graphDialog.ui" line="153"/>
+        <location filename="../ui/graphDialog.ui" line="156"/>
+        <location filename="../ui/graphDialog.ui" line="159"/>
         <source>Save to DOT file</source>
         <translation>점 파일에 저장</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="123"/>
-        <location filename="../ui/graphDialog.ui" line="126"/>
-        <location filename="../ui/graphDialog.ui" line="129"/>
+        <location filename="../ui/graphDialog.ui" line="172"/>
+        <location filename="../ui/graphDialog.ui" line="175"/>
+        <location filename="../ui/graphDialog.ui" line="178"/>
         <source>Save Image</source>
         <translation>이미지 저장</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="142"/>
-        <location filename="../ui/graphDialog.ui" line="145"/>
-        <location filename="../ui/graphDialog.ui" line="148"/>
+        <location filename="../ui/graphDialog.ui" line="191"/>
+        <location filename="../ui/graphDialog.ui" line="194"/>
+        <location filename="../ui/graphDialog.ui" line="197"/>
         <source>Close</source>
         <translation>닫기</translation>
     </message>
@@ -55,196 +60,206 @@
         <translation>CodeQuery</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="29"/>
-        <location filename="../ui/mainWindow.ui" line="32"/>
+        <location filename="../ui/mainWindow.ui" line="27"/>
+        <location filename="../ui/mainWindow.ui" line="30"/>
         <source>Open Database</source>
         <translation>데이터베이스 열기</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="69"/>
+        <location filename="../ui/mainWindow.ui" line="76"/>
         <source>Auto-complete</source>
         <translation>자동 완성</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="83"/>
+        <location filename="../ui/mainWindow.ui" line="90"/>
         <source>Exact match</source>
         <translation>정확 하 게 일치</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="97"/>
-        <location filename="../ui/mainWindow.ui" line="100"/>
+        <location filename="../ui/mainWindow.ui" line="104"/>
+        <location filename="../ui/mainWindow.ui" line="107"/>
         <source>File path filter</source>
         <translation>파일 경로 필터</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="103"/>
+        <location filename="../ui/mainWindow.ui" line="110"/>
         <source>Filter</source>
         <translation>필터</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="119"/>
-        <location filename="../ui/mainWindow.ui" line="122"/>
+        <location filename="../ui/mainWindow.ui" line="126"/>
+        <location filename="../ui/mainWindow.ui" line="129"/>
         <source>File path filter, wildcard searches (* and ?) are supported</source>
         <translation>파일 경로 필터, 와일드 카드 검색 (* 및?) 지원</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="145"/>
-        <location filename="../ui/mainWindow.ui" line="148"/>
+        <location filename="../ui/mainWindow.ui" line="152"/>
+        <location filename="../ui/mainWindow.ui" line="155"/>
         <source>Previous search term</source>
         <translation>이전 검색어</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="162"/>
-        <location filename="../ui/mainWindow.ui" line="165"/>
+        <location filename="../ui/mainWindow.ui" line="175"/>
+        <location filename="../ui/mainWindow.ui" line="178"/>
         <source>Next search term</source>
         <translation>다음 검색어</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="185"/>
-        <location filename="../ui/mainWindow.ui" line="188"/>
+        <location filename="../ui/mainWindow.ui" line="204"/>
+        <location filename="../ui/mainWindow.ui" line="207"/>
         <source>If Exact Match is switched off, wildcard searches (* and ?) are supported</source>
         <translation>정확히 일치 하는 와일드 카드 검색을 전환 하는 경우 (* 및?) 지원</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="204"/>
-        <location filename="../ui/mainWindow.ui" line="207"/>
+        <location filename="../ui/mainWindow.ui" line="226"/>
+        <location filename="../ui/mainWindow.ui" line="229"/>
         <source>Search</source>
         <translation>검색</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="221"/>
-        <location filename="../ui/mainWindow.ui" line="224"/>
+        <location filename="../ui/mainWindow.ui" line="249"/>
+        <location filename="../ui/mainWindow.ui" line="252"/>
         <source>Paste and Search</source>
         <translation>붙여넣기 및 검색</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="241"/>
-        <location filename="../ui/mainWindow.ui" line="244"/>
+        <location filename="../ui/mainWindow.ui" line="275"/>
+        <location filename="../ui/mainWindow.ui" line="278"/>
         <source>Draw graph</source>
         <translation>그래프 그리기</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="295"/>
-        <location filename="../ui/mainWindow.ui" line="298"/>
+        <location filename="../ui/mainWindow.ui" line="335"/>
+        <location filename="../ui/mainWindow.ui" line="338"/>
         <source>Previous File</source>
         <translation>이전 파일</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="312"/>
-        <location filename="../ui/mainWindow.ui" line="315"/>
+        <location filename="../ui/mainWindow.ui" line="358"/>
+        <location filename="../ui/mainWindow.ui" line="361"/>
         <source>Next File</source>
         <translation>다음 파일</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="329"/>
-        <location filename="../ui/mainWindow.ui" line="332"/>
+        <location filename="../ui/mainWindow.ui" line="381"/>
+        <location filename="../ui/mainWindow.ui" line="384"/>
         <source>Open in Editor</source>
         <translation>편집기에서 열려</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="346"/>
-        <location filename="../ui/mainWindow.ui" line="349"/>
+        <location filename="../ui/mainWindow.ui" line="404"/>
+        <location filename="../ui/mainWindow.ui" line="407"/>
         <source>Go to selected line</source>
         <translation>선택 된 줄으로 이동</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="363"/>
-        <location filename="../ui/mainWindow.ui" line="366"/>
+        <location filename="../ui/mainWindow.ui" line="427"/>
+        <location filename="../ui/mainWindow.ui" line="430"/>
         <source>Reduce font size</source>
         <translation>글꼴 크기 줄이기</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="380"/>
-        <location filename="../ui/mainWindow.ui" line="383"/>
+        <location filename="../ui/mainWindow.ui" line="450"/>
+        <location filename="../ui/mainWindow.ui" line="453"/>
         <source>Increase font size</source>
         <translation>글꼴 크기 증가</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="404"/>
-        <location filename="../ui/mainWindow.ui" line="407"/>
+        <location filename="../ui/mainWindow.ui" line="480"/>
+        <location filename="../ui/mainWindow.ui" line="483"/>
         <source>Copy, paste and search</source>
         <translation>복사, 붙여넣기 및 검색</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="421"/>
-        <location filename="../ui/mainWindow.ui" line="424"/>
+        <location filename="../ui/mainWindow.ui" line="503"/>
+        <location filename="../ui/mainWindow.ui" line="506"/>
         <source>Symbol search only for paste and search</source>
         <translation>붙여넣기 및 검색에 대해서만 기호 검색</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="427"/>
+        <location filename="../ui/mainWindow.ui" line="509"/>
         <source>Symbol only</source>
         <translation>상징만</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="441"/>
-        <location filename="../ui/mainWindow.ui" line="444"/>
+        <location filename="../ui/mainWindow.ui" line="523"/>
+        <location filename="../ui/mainWindow.ui" line="526"/>
         <source>Previous search result in this file</source>
         <translation>이 파일에서 이전 검색 결과</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="458"/>
-        <location filename="../ui/mainWindow.ui" line="461"/>
+        <location filename="../ui/mainWindow.ui" line="546"/>
+        <location filename="../ui/mainWindow.ui" line="549"/>
         <source>Next search result in this file</source>
         <translation>이 파일에서 다음 검색 결과</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="487"/>
+        <location filename="../ui/mainWindow.ui" line="581"/>
         <source>FilePath:0</source>
         <translation>FilePath:0</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="528"/>
+        <location filename="../ui/mainWindow.ui" line="610"/>
+        <source>Sort by line number</source>
+        <translation>줄 번호로 정렬 합니다</translation>
+    </message>
+    <message>
+        <location filename="../ui/mainWindow.ui" line="615"/>
+        <source>Sort by name</source>
+        <translation>이름으로 정렬 합니다</translation>
+    </message>
+    <message>
+        <location filename="../ui/mainWindow.ui" line="665"/>
         <source>File</source>
         <translation>파일</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="535"/>
+        <location filename="../ui/mainWindow.ui" line="672"/>
         <source>Options</source>
         <translation>옵션</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="543"/>
+        <location filename="../ui/mainWindow.ui" line="680"/>
         <source>Help</source>
         <translation>도움말</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="555"/>
+        <location filename="../ui/mainWindow.ui" line="692"/>
         <source>Exit</source>
         <translation>출구</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="563"/>
+        <location filename="../ui/mainWindow.ui" line="700"/>
         <source>Open</source>
         <translation>오픈</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="568"/>
+        <location filename="../ui/mainWindow.ui" line="705"/>
         <source>About</source>
         <translation>에 대 한</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="573"/>
+        <location filename="../ui/mainWindow.ui" line="710"/>
         <source>External Editor</source>
         <translation>외부 편집기</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="578"/>
+        <location filename="../ui/mainWindow.ui" line="715"/>
         <source>Open CQ Database</source>
         <translation>오픈 CQ 데이터베이스</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="583"/>
+        <location filename="../ui/mainWindow.ui" line="720"/>
         <source>Language</source>
         <translation>언어</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="588"/>
+        <location filename="../ui/mainWindow.ui" line="725"/>
         <source>About Qt</source>
         <translation>Qt에 대 한</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="596"/>
+        <location filename="../ui/mainWindow.ui" line="733"/>
         <source>File Viewer Settings</source>
         <translation>파일 뷰어 설정</translation>
     </message>
@@ -265,23 +280,23 @@
 <context>
     <name>cqDialogGraph</name>
     <message>
-        <location filename="../graphdialog.cpp" line="78"/>
+        <location filename="../graphdialog.cpp" line="89"/>
         <source>Images</source>
         <translation>이미지</translation>
     </message>
     <message>
-        <location filename="../graphdialog.cpp" line="81"/>
+        <location filename="../graphdialog.cpp" line="92"/>
         <source>Export Image</source>
         <translation>이미지 내보내기</translation>
     </message>
     <message>
-        <location filename="../graphdialog.cpp" line="92"/>
-        <location filename="../graphdialog.cpp" line="111"/>
+        <location filename="../graphdialog.cpp" line="103"/>
+        <location filename="../graphdialog.cpp" line="122"/>
         <source>File could not be saved!</source>
         <translation>파일을 저장할 수 없습니다!</translation>
     </message>
     <message>
-        <location filename="../graphdialog.cpp" line="100"/>
+        <location filename="../graphdialog.cpp" line="111"/>
         <source>Export DOT file</source>
         <translation>도트 파일 내보내기</translation>
     </message>
@@ -322,62 +337,62 @@
 <context>
     <name>fileviewer</name>
     <message>
-        <location filename="../fileviewer.cpp" line="189"/>
+        <location filename="../fileviewer.cpp" line="249"/>
         <source>File not found</source>
         <translation>파일을 찾을 수 없습니다</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="196"/>
+        <location filename="../fileviewer.cpp" line="256"/>
         <source>File could not be opened</source>
         <translation>파일을 열 수 없습니다.</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="210"/>
+        <location filename="../fileviewer.cpp" line="270"/>
         <source>The source file to be viewed is newer than the CodeQuery database file. You are recommended to manually regenerate the CodeQuery database file.</source>
         <translation>소스 파일을 볼 수 CodeQuery 데이터베이스 파일 보다 최신입니다. CodeQuery 데이터베이스 파일을 수동으로 다시 생성 하는 것이 좋습니다.</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="447"/>
+        <location filename="../fileviewer.cpp" line="533"/>
         <source>Cancel</source>
         <translation>취소</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="448"/>
+        <location filename="../fileviewer.cpp" line="534"/>
         <source>OK</source>
         <translation>괜찮았던 것</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="450"/>
+        <location filename="../fileviewer.cpp" line="536"/>
         <source>External Editor Configuration</source>
         <translation>외부 편집기 구성</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="451"/>
+        <location filename="../fileviewer.cpp" line="537"/>
         <source>Please enter the path and arguments for the external editor. Replace as follows:</source>
         <translation>경로 및 외부 편집기에 대 한 인수를 입력 해 주시기 바랍니다. 다음과 같이 바꿉니다.</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="453"/>
+        <location filename="../fileviewer.cpp" line="539"/>
         <source>for file path</source>
         <translation>파일 경로 대 한</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="455"/>
+        <location filename="../fileviewer.cpp" line="541"/>
         <source>for line number</source>
         <translation>줄 번호에 대 한</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="457"/>
+        <location filename="../fileviewer.cpp" line="543"/>
         <source>For example:</source>
         <translation>예를 들어:</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="482"/>
+        <location filename="../fileviewer.cpp" line="568"/>
         <source>File could not be opened!</source>
         <translation>파일을 열 수 없습니다!</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="507"/>
+        <location filename="../fileviewer.cpp" line="593"/>
         <source>External editor could not be started. Please check Options!</source>
         <translation>외부 편집기를 시작할 수 없습니다. 옵션을 확인 하십시오!</translation>
     </message>
@@ -385,22 +400,22 @@
 <context>
     <name>listhandler</name>
     <message>
-        <location filename="../listhandler.cpp" line="128"/>
+        <location filename="../listhandler.cpp" line="129"/>
         <source>Symbol</source>
         <translation>기호</translation>
     </message>
     <message>
-        <location filename="../listhandler.cpp" line="129"/>
+        <location filename="../listhandler.cpp" line="130"/>
         <source>File</source>
         <translation>파일</translation>
     </message>
     <message>
-        <location filename="../listhandler.cpp" line="132"/>
+        <location filename="../listhandler.cpp" line="133"/>
         <source>Line</source>
         <translation>선</translation>
     </message>
     <message>
-        <location filename="../listhandler.cpp" line="132"/>
+        <location filename="../listhandler.cpp" line="133"/>
         <source>Preview</source>
         <translation>미리 보기</translation>
     </message>
@@ -408,22 +423,22 @@
 <context>
     <name>mainwindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="156"/>
+        <location filename="../mainwindow.cpp" line="168"/>
         <source>Cancel</source>
         <translation>취소</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="157"/>
+        <location filename="../mainwindow.cpp" line="169"/>
         <source>OK</source>
         <translation>괜찮았던 것</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="159"/>
+        <location filename="../mainwindow.cpp" line="171"/>
         <source>Language</source>
         <translation>언어</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="160"/>
+        <location filename="../mainwindow.cpp" line="172"/>
         <source>Select language:</source>
         <translation>언어 선택:</translation>
     </message>
@@ -431,138 +446,138 @@
 <context>
     <name>searchhandler</name>
     <message>
-        <location filename="../searchhandler.cpp" line="250"/>
+        <location filename="../searchhandler.cpp" line="334"/>
         <source>Symbol</source>
         <translation>기호</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="253"/>
+        <location filename="../searchhandler.cpp" line="337"/>
         <source>Function or macro definition (Graph available)</source>
         <translation>함수 또는 매크로 정의 (그래프 제공)</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="265"/>
+        <location filename="../searchhandler.cpp" line="349"/>
         <source>Class or struct (Graph available)</source>
         <translation>클래스 또는 구조체 (그래프 제공)</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="259"/>
+        <location filename="../searchhandler.cpp" line="343"/>
         <source>Functions calling this function</source>
         <translation>이 함수를 호출 하는 함수</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="262"/>
+        <location filename="../searchhandler.cpp" line="346"/>
         <source>Functions called by this function</source>
         <translation>이 함수에 의해 호출 된 함수</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="256"/>
+        <location filename="../searchhandler.cpp" line="340"/>
         <source>Calls of this function or macro</source>
         <translation>이 함수 또는 매크로의 호출</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="268"/>
+        <location filename="../searchhandler.cpp" line="352"/>
         <source>Class which owns this member or method</source>
         <translation>클래스 멤버 또는 메서드가 소유 하 고 있는</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="271"/>
+        <location filename="../searchhandler.cpp" line="355"/>
         <source>Members or methods of this class</source>
         <translation>회원 또는이 클래스의 메서드</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="274"/>
+        <location filename="../searchhandler.cpp" line="358"/>
         <source>Parent of this class</source>
         <translation>이 클래스의 부모</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="277"/>
+        <location filename="../searchhandler.cpp" line="361"/>
         <source>Children of this class</source>
         <translation>이 클래스의 자식</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="280"/>
+        <location filename="../searchhandler.cpp" line="364"/>
         <source>Files including this file</source>
         <translation>이 파일을 포함 한 파일</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="283"/>
+        <location filename="../searchhandler.cpp" line="367"/>
         <source>Full path for file</source>
         <translation>파일의 전체 경로</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="286"/>
+        <location filename="../searchhandler.cpp" line="370"/>
         <source>Functions or macros inside this file</source>
         <translation>이 파일 안에 매크로 또는 함수</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="297"/>
+        <location filename="../searchhandler.cpp" line="381"/>
         <source>CodeQuery DB Files</source>
         <translation>CodeQuery DB 파일</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="300"/>
+        <location filename="../searchhandler.cpp" line="384"/>
         <source>Open CQ database file</source>
         <translation>CQ 데이터베이스 파일 열기</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="359"/>
+        <location filename="../searchhandler.cpp" line="453"/>
         <source>Function Call Graph</source>
         <translation>함수 호출 그래프</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="363"/>
+        <location filename="../searchhandler.cpp" line="457"/>
         <source>Class Inheritance Graph</source>
         <translation>클래스 상속 그래프</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="379"/>
-        <location filename="../searchhandler.cpp" line="382"/>
+        <location filename="../searchhandler.cpp" line="473"/>
+        <location filename="../searchhandler.cpp" line="476"/>
         <source>If Exact Match is switched off, wildcard searches (* and ?) are supported</source>
         <translation>정확히 일치 하는 와일드 카드 검색을 전환 하는 경우 (* 및?) 지원</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="444"/>
+        <location filename="../searchhandler.cpp" line="548"/>
         <source>results found</source>
         <translation>찾은 결과</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="463"/>
+        <location filename="../searchhandler.cpp" line="567"/>
         <source>in progress</source>
         <translation>진행 중</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="464"/>
+        <location filename="../searchhandler.cpp" line="568"/>
         <source>Cancel</source>
         <translation>취소</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="561"/>
+        <location filename="../searchhandler.cpp" line="665"/>
         <source>You have to first select an item from the list before pushing the Graph button.</source>
         <translation>먼저 그래프 버튼을 추진 하기 전에 목록에서 항목을 선택 해야 합니다.</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="673"/>
+        <location filename="../searchhandler.cpp" line="794"/>
         <source>File open error</source>
         <translation>파일 열기 오류</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="674"/>
+        <location filename="../searchhandler.cpp" line="795"/>
         <source>Wrong file format</source>
         <translation>잘못 된 파일 형식</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="675"/>
+        <location filename="../searchhandler.cpp" line="796"/>
         <source>Incorrect CQ database version</source>
         <translation>잘못 된 CQ 데이터베이스 버전</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="676"/>
+        <location filename="../searchhandler.cpp" line="797"/>
         <source>OK</source>
         <translation>괜찮았던 것</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="678"/>
+        <location filename="../searchhandler.cpp" line="799"/>
         <source>Unknown Error</source>
         <translation>알 수 없는 오류</translation>
     </message>
