@@ -14,35 +14,40 @@
         <translation>請稍候。。。</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="64"/>
-        <location filename="../ui/graphDialog.ui" line="67"/>
+        <location filename="../ui/graphDialog.ui" line="70"/>
+        <location filename="../ui/graphDialog.ui" line="73"/>
         <source>Zoom Out</source>
         <translation>縮小</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="81"/>
-        <location filename="../ui/graphDialog.ui" line="84"/>
+        <location filename="../ui/graphDialog.ui" line="93"/>
+        <location filename="../ui/graphDialog.ui" line="96"/>
         <source>Zoom In</source>
         <translation>放大</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="104"/>
-        <location filename="../ui/graphDialog.ui" line="107"/>
-        <location filename="../ui/graphDialog.ui" line="110"/>
+        <location filename="../ui/graphDialog.ui" line="123"/>
+        <source>Number of levels:</source>
+        <translation>級別數:</translation>
+    </message>
+    <message>
+        <location filename="../ui/graphDialog.ui" line="153"/>
+        <location filename="../ui/graphDialog.ui" line="156"/>
+        <location filename="../ui/graphDialog.ui" line="159"/>
         <source>Save to DOT file</source>
         <translation>將保存到點檔</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="123"/>
-        <location filename="../ui/graphDialog.ui" line="126"/>
-        <location filename="../ui/graphDialog.ui" line="129"/>
+        <location filename="../ui/graphDialog.ui" line="172"/>
+        <location filename="../ui/graphDialog.ui" line="175"/>
+        <location filename="../ui/graphDialog.ui" line="178"/>
         <source>Save Image</source>
         <translation>保存圖像</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="142"/>
-        <location filename="../ui/graphDialog.ui" line="145"/>
-        <location filename="../ui/graphDialog.ui" line="148"/>
+        <location filename="../ui/graphDialog.ui" line="191"/>
+        <location filename="../ui/graphDialog.ui" line="194"/>
+        <location filename="../ui/graphDialog.ui" line="197"/>
         <source>Close</source>
         <translation>關閉</translation>
     </message>
@@ -55,196 +60,206 @@
         <translation>CodeQuery</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="29"/>
-        <location filename="../ui/mainWindow.ui" line="32"/>
+        <location filename="../ui/mainWindow.ui" line="27"/>
+        <location filename="../ui/mainWindow.ui" line="30"/>
         <source>Open Database</source>
         <translation>打開的資料庫</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="69"/>
+        <location filename="../ui/mainWindow.ui" line="76"/>
         <source>Auto-complete</source>
         <translation>自動完成</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="83"/>
+        <location filename="../ui/mainWindow.ui" line="90"/>
         <source>Exact match</source>
         <translation>精確匹配</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="97"/>
-        <location filename="../ui/mainWindow.ui" line="100"/>
+        <location filename="../ui/mainWindow.ui" line="104"/>
+        <location filename="../ui/mainWindow.ui" line="107"/>
         <source>File path filter</source>
         <translation>檔路徑篩選器</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="103"/>
+        <location filename="../ui/mainWindow.ui" line="110"/>
         <source>Filter</source>
         <translation>篩選器</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="119"/>
-        <location filename="../ui/mainWindow.ui" line="122"/>
+        <location filename="../ui/mainWindow.ui" line="126"/>
+        <location filename="../ui/mainWindow.ui" line="129"/>
         <source>File path filter, wildcard searches (* and ?) are supported</source>
         <translation>檔路徑篩選器、 萬用字元搜尋 （* 和?） 支援</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="145"/>
-        <location filename="../ui/mainWindow.ui" line="148"/>
+        <location filename="../ui/mainWindow.ui" line="152"/>
+        <location filename="../ui/mainWindow.ui" line="155"/>
         <source>Previous search term</source>
         <translation>以前的搜索詞</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="162"/>
-        <location filename="../ui/mainWindow.ui" line="165"/>
+        <location filename="../ui/mainWindow.ui" line="175"/>
+        <location filename="../ui/mainWindow.ui" line="178"/>
         <source>Next search term</source>
         <translation>下一個搜索詞</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="185"/>
-        <location filename="../ui/mainWindow.ui" line="188"/>
+        <location filename="../ui/mainWindow.ui" line="204"/>
+        <location filename="../ui/mainWindow.ui" line="207"/>
         <source>If Exact Match is switched off, wildcard searches (* and ?) are supported</source>
         <translation>如果精確匹配關掉，萬用字元搜尋 （* 和?） 支援</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="204"/>
-        <location filename="../ui/mainWindow.ui" line="207"/>
+        <location filename="../ui/mainWindow.ui" line="226"/>
+        <location filename="../ui/mainWindow.ui" line="229"/>
         <source>Search</source>
         <translation>搜索</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="221"/>
-        <location filename="../ui/mainWindow.ui" line="224"/>
+        <location filename="../ui/mainWindow.ui" line="249"/>
+        <location filename="../ui/mainWindow.ui" line="252"/>
         <source>Paste and Search</source>
         <translation>粘貼並搜索</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="241"/>
-        <location filename="../ui/mainWindow.ui" line="244"/>
+        <location filename="../ui/mainWindow.ui" line="275"/>
+        <location filename="../ui/mainWindow.ui" line="278"/>
         <source>Draw graph</source>
         <translation>繪製關係圖</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="295"/>
-        <location filename="../ui/mainWindow.ui" line="298"/>
+        <location filename="../ui/mainWindow.ui" line="335"/>
+        <location filename="../ui/mainWindow.ui" line="338"/>
         <source>Previous File</source>
         <translation>以前的檔</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="312"/>
-        <location filename="../ui/mainWindow.ui" line="315"/>
+        <location filename="../ui/mainWindow.ui" line="358"/>
+        <location filename="../ui/mainWindow.ui" line="361"/>
         <source>Next File</source>
         <translation>下一個檔</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="329"/>
-        <location filename="../ui/mainWindow.ui" line="332"/>
+        <location filename="../ui/mainWindow.ui" line="381"/>
+        <location filename="../ui/mainWindow.ui" line="384"/>
         <source>Open in Editor</source>
         <translation>在編輯器中打開</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="346"/>
-        <location filename="../ui/mainWindow.ui" line="349"/>
+        <location filename="../ui/mainWindow.ui" line="404"/>
+        <location filename="../ui/mainWindow.ui" line="407"/>
         <source>Go to selected line</source>
         <translation>轉到所選行</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="363"/>
-        <location filename="../ui/mainWindow.ui" line="366"/>
+        <location filename="../ui/mainWindow.ui" line="427"/>
+        <location filename="../ui/mainWindow.ui" line="430"/>
         <source>Reduce font size</source>
         <translation>減小字體大小</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="380"/>
-        <location filename="../ui/mainWindow.ui" line="383"/>
+        <location filename="../ui/mainWindow.ui" line="450"/>
+        <location filename="../ui/mainWindow.ui" line="453"/>
         <source>Increase font size</source>
         <translation>增加字體大小</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="404"/>
-        <location filename="../ui/mainWindow.ui" line="407"/>
+        <location filename="../ui/mainWindow.ui" line="480"/>
+        <location filename="../ui/mainWindow.ui" line="483"/>
         <source>Copy, paste and search</source>
         <translation>複製、 粘貼和搜索</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="421"/>
-        <location filename="../ui/mainWindow.ui" line="424"/>
+        <location filename="../ui/mainWindow.ui" line="503"/>
+        <location filename="../ui/mainWindow.ui" line="506"/>
         <source>Symbol search only for paste and search</source>
         <translation>僅用於粘貼和搜索符號搜索</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="427"/>
+        <location filename="../ui/mainWindow.ui" line="509"/>
         <source>Symbol only</source>
         <translation>只有符號</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="441"/>
-        <location filename="../ui/mainWindow.ui" line="444"/>
+        <location filename="../ui/mainWindow.ui" line="523"/>
+        <location filename="../ui/mainWindow.ui" line="526"/>
         <source>Previous search result in this file</source>
         <translation>此檔中的上一個搜尋結果</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="458"/>
-        <location filename="../ui/mainWindow.ui" line="461"/>
+        <location filename="../ui/mainWindow.ui" line="546"/>
+        <location filename="../ui/mainWindow.ui" line="549"/>
         <source>Next search result in this file</source>
         <translation>在此檔中的下一個搜尋結果</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="487"/>
+        <location filename="../ui/mainWindow.ui" line="581"/>
         <source>FilePath:0</source>
         <translation>FilePath:0</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="528"/>
+        <location filename="../ui/mainWindow.ui" line="610"/>
+        <source>Sort by line number</source>
+        <translation>按行號排序</translation>
+    </message>
+    <message>
+        <location filename="../ui/mainWindow.ui" line="615"/>
+        <source>Sort by name</source>
+        <translation>按名稱排序</translation>
+    </message>
+    <message>
+        <location filename="../ui/mainWindow.ui" line="665"/>
         <source>File</source>
         <translation>檔</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="535"/>
+        <location filename="../ui/mainWindow.ui" line="672"/>
         <source>Options</source>
         <translation>選項</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="543"/>
+        <location filename="../ui/mainWindow.ui" line="680"/>
         <source>Help</source>
         <translation>説明</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="555"/>
+        <location filename="../ui/mainWindow.ui" line="692"/>
         <source>Exit</source>
         <translation>退出</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="563"/>
+        <location filename="../ui/mainWindow.ui" line="700"/>
         <source>Open</source>
         <translation>開放</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="568"/>
+        <location filename="../ui/mainWindow.ui" line="705"/>
         <source>About</source>
         <translation>關於</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="573"/>
+        <location filename="../ui/mainWindow.ui" line="710"/>
         <source>External Editor</source>
         <translation>外部編輯器</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="578"/>
+        <location filename="../ui/mainWindow.ui" line="715"/>
         <source>Open CQ Database</source>
         <translation>打開 CQ 資料庫</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="583"/>
+        <location filename="../ui/mainWindow.ui" line="720"/>
         <source>Language</source>
         <translation>語言</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="588"/>
+        <location filename="../ui/mainWindow.ui" line="725"/>
         <source>About Qt</source>
         <translation>關於 Qt</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="596"/>
+        <location filename="../ui/mainWindow.ui" line="733"/>
         <source>File Viewer Settings</source>
         <translation>檔檢視器設置</translation>
     </message>
@@ -265,23 +280,23 @@
 <context>
     <name>cqDialogGraph</name>
     <message>
-        <location filename="../graphdialog.cpp" line="78"/>
+        <location filename="../graphdialog.cpp" line="89"/>
         <source>Images</source>
         <translation>圖像</translation>
     </message>
     <message>
-        <location filename="../graphdialog.cpp" line="81"/>
+        <location filename="../graphdialog.cpp" line="92"/>
         <source>Export Image</source>
         <translation>匯出圖像</translation>
     </message>
     <message>
-        <location filename="../graphdialog.cpp" line="92"/>
-        <location filename="../graphdialog.cpp" line="111"/>
+        <location filename="../graphdialog.cpp" line="103"/>
+        <location filename="../graphdialog.cpp" line="122"/>
         <source>File could not be saved!</source>
         <translation>無法保存檔 ！</translation>
     </message>
     <message>
-        <location filename="../graphdialog.cpp" line="100"/>
+        <location filename="../graphdialog.cpp" line="111"/>
         <source>Export DOT file</source>
         <translation>出口點檔</translation>
     </message>
@@ -322,62 +337,62 @@
 <context>
     <name>fileviewer</name>
     <message>
-        <location filename="../fileviewer.cpp" line="189"/>
+        <location filename="../fileviewer.cpp" line="249"/>
         <source>File not found</source>
         <translation>找不到檔</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="196"/>
+        <location filename="../fileviewer.cpp" line="256"/>
         <source>File could not be opened</source>
         <translation>不能打開檔</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="210"/>
+        <location filename="../fileviewer.cpp" line="270"/>
         <source>The source file to be viewed is newer than the CodeQuery database file. You are recommended to manually regenerate the CodeQuery database file.</source>
         <translation>要查看原始檔案是比 CodeQuery 資料庫檔案更新。建議您手動重新生成的 CodeQuery 資料庫檔案。</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="447"/>
+        <location filename="../fileviewer.cpp" line="533"/>
         <source>Cancel</source>
         <translation>取消</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="448"/>
+        <location filename="../fileviewer.cpp" line="534"/>
         <source>OK</source>
         <translation>還行</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="450"/>
+        <location filename="../fileviewer.cpp" line="536"/>
         <source>External Editor Configuration</source>
         <translation>外部編輯器配置</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="451"/>
+        <location filename="../fileviewer.cpp" line="537"/>
         <source>Please enter the path and arguments for the external editor. Replace as follows:</source>
         <translation>請輸入路徑和參數的外部編輯器。替換，如下所示：</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="453"/>
+        <location filename="../fileviewer.cpp" line="539"/>
         <source>for file path</source>
         <translation>檔路徑</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="455"/>
+        <location filename="../fileviewer.cpp" line="541"/>
         <source>for line number</source>
         <translation>為行號</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="457"/>
+        <location filename="../fileviewer.cpp" line="543"/>
         <source>For example:</source>
         <translation>例如：</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="482"/>
+        <location filename="../fileviewer.cpp" line="568"/>
         <source>File could not be opened!</source>
         <translation>不能打開檔 ！</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="507"/>
+        <location filename="../fileviewer.cpp" line="593"/>
         <source>External editor could not be started. Please check Options!</source>
         <translation>無法啟動外部編輯器。請檢查選項 ！</translation>
     </message>
@@ -385,22 +400,22 @@
 <context>
     <name>listhandler</name>
     <message>
-        <location filename="../listhandler.cpp" line="128"/>
+        <location filename="../listhandler.cpp" line="129"/>
         <source>Symbol</source>
         <translation>符號</translation>
     </message>
     <message>
-        <location filename="../listhandler.cpp" line="129"/>
+        <location filename="../listhandler.cpp" line="130"/>
         <source>File</source>
         <translation>檔</translation>
     </message>
     <message>
-        <location filename="../listhandler.cpp" line="132"/>
+        <location filename="../listhandler.cpp" line="133"/>
         <source>Line</source>
         <translation>行</translation>
     </message>
     <message>
-        <location filename="../listhandler.cpp" line="132"/>
+        <location filename="../listhandler.cpp" line="133"/>
         <source>Preview</source>
         <translation>預覽</translation>
     </message>
@@ -408,22 +423,22 @@
 <context>
     <name>mainwindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="156"/>
+        <location filename="../mainwindow.cpp" line="168"/>
         <source>Cancel</source>
         <translation>取消</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="157"/>
+        <location filename="../mainwindow.cpp" line="169"/>
         <source>OK</source>
         <translation>還行</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="159"/>
+        <location filename="../mainwindow.cpp" line="171"/>
         <source>Language</source>
         <translation>語言</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="160"/>
+        <location filename="../mainwindow.cpp" line="172"/>
         <source>Select language:</source>
         <translation>選擇語言：</translation>
     </message>
@@ -431,138 +446,138 @@
 <context>
     <name>searchhandler</name>
     <message>
-        <location filename="../searchhandler.cpp" line="250"/>
+        <location filename="../searchhandler.cpp" line="334"/>
         <source>Symbol</source>
         <translation>符號</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="253"/>
+        <location filename="../searchhandler.cpp" line="337"/>
         <source>Function or macro definition (Graph available)</source>
         <translation>函數或宏的定義 （Graph 中可用)</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="265"/>
+        <location filename="../searchhandler.cpp" line="349"/>
         <source>Class or struct (Graph available)</source>
         <translation>類或結構 （Graph 中可用）</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="259"/>
+        <location filename="../searchhandler.cpp" line="343"/>
         <source>Functions calling this function</source>
         <translation>調用此函數的函數</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="262"/>
+        <location filename="../searchhandler.cpp" line="346"/>
         <source>Functions called by this function</source>
         <translation>此函式呼叫的函數</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="256"/>
+        <location filename="../searchhandler.cpp" line="340"/>
         <source>Calls of this function or macro</source>
         <translation>此函數或宏的調用</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="268"/>
+        <location filename="../searchhandler.cpp" line="352"/>
         <source>Class which owns this member or method</source>
         <translation>擁有此成員或方法的類</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="271"/>
+        <location filename="../searchhandler.cpp" line="355"/>
         <source>Members or methods of this class</source>
         <translation>此類方法或成員</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="274"/>
+        <location filename="../searchhandler.cpp" line="358"/>
         <source>Parent of this class</source>
         <translation>此類的父</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="277"/>
+        <location filename="../searchhandler.cpp" line="361"/>
         <source>Children of this class</source>
         <translation>兒童的此類</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="280"/>
+        <location filename="../searchhandler.cpp" line="364"/>
         <source>Files including this file</source>
         <translation>此檔包括檔</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="283"/>
+        <location filename="../searchhandler.cpp" line="367"/>
         <source>Full path for file</source>
         <translation>檔的完整路徑</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="286"/>
+        <location filename="../searchhandler.cpp" line="370"/>
         <source>Functions or macros inside this file</source>
         <translation>函數或此檔中的宏</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="297"/>
+        <location filename="../searchhandler.cpp" line="381"/>
         <source>CodeQuery DB Files</source>
         <translation>CodeQuery DB 檔</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="300"/>
+        <location filename="../searchhandler.cpp" line="384"/>
         <source>Open CQ database file</source>
         <translation>打開 CQ 資料庫檔案</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="359"/>
+        <location filename="../searchhandler.cpp" line="453"/>
         <source>Function Call Graph</source>
         <translation>函數的調用關係圖</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="363"/>
+        <location filename="../searchhandler.cpp" line="457"/>
         <source>Class Inheritance Graph</source>
         <translation>類繼承關係圖</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="379"/>
-        <location filename="../searchhandler.cpp" line="382"/>
+        <location filename="../searchhandler.cpp" line="473"/>
+        <location filename="../searchhandler.cpp" line="476"/>
         <source>If Exact Match is switched off, wildcard searches (* and ?) are supported</source>
         <translation>如果精確匹配關掉，萬用字元搜尋 （* 和?） 支援</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="444"/>
+        <location filename="../searchhandler.cpp" line="548"/>
         <source>results found</source>
         <translation>找到的結果</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="463"/>
+        <location filename="../searchhandler.cpp" line="567"/>
         <source>in progress</source>
         <translation>在進行中</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="464"/>
+        <location filename="../searchhandler.cpp" line="568"/>
         <source>Cancel</source>
         <translation>取消</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="561"/>
+        <location filename="../searchhandler.cpp" line="665"/>
         <source>You have to first select an item from the list before pushing the Graph button.</source>
         <translation>您必須先推圖形按鈕之前從清單中選擇一個項。</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="673"/>
+        <location filename="../searchhandler.cpp" line="794"/>
         <source>File open error</source>
         <translation>檔打開錯誤</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="674"/>
+        <location filename="../searchhandler.cpp" line="795"/>
         <source>Wrong file format</source>
         <translation>錯誤的檔案格式</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="675"/>
+        <location filename="../searchhandler.cpp" line="796"/>
         <source>Incorrect CQ database version</source>
         <translation>CQ 資料庫版本不正確</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="676"/>
+        <location filename="../searchhandler.cpp" line="797"/>
         <source>OK</source>
         <translation>還行</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="678"/>
+        <location filename="../searchhandler.cpp" line="799"/>
         <source>Unknown Error</source>
         <translation>未知的錯誤</translation>
     </message>
